package com.ruoyi.ss.vipLevel.service.impl;

import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.ss.store.domain.StoreVo;
import com.ruoyi.ss.store.service.StoreService;
import com.ruoyi.ss.vipLevel.domain.VipLevelVO;
import com.ruoyi.ss.vipLevel.service.VipLevelAssembler;
import com.ruoyi.ss.vipLevelSku.domain.VipLevelSkuVO;
import com.ruoyi.ss.vipLevelSku.service.VipLevelSkuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class VipLevelAssemblerImpl implements VipLevelAssembler {

    @Autowired
    private StoreService storeService;

    @Autowired
    private VipLevelSkuService vipLevelSkuService;

    @Override
    public void assembleStoreList(List<VipLevelVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        List<Long> storeIds = list.stream().map(VipLevelVO::getStoreIds).flatMap(Collection::stream).collect(Collectors.toList());
        List<StoreVo> storeList = storeService.selectStoreByIds(storeIds);

        for (VipLevelVO vipLevel : list) {
            List<StoreVo> vipLevelStoreList = storeList.stream()
                .filter(store -> vipLevel.getStoreIds().contains(store.getStoreId()))
                .collect(Collectors.toList());
            vipLevel.setStoreList(vipLevelStoreList);
        }
    }

    @Override
    public void assembleSkuList(List<VipLevelVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        List<Long> levelIds = list.stream().map(VipLevelVO::getId).collect(Collectors.toList());

        Map<Long, List<VipLevelSkuVO>> group = vipLevelSkuService.selectByLevelIds(levelIds)
            .stream().collect(Collectors.groupingBy(VipLevelSkuVO::getLevelId));


        for (VipLevelVO vipLevel : list) {
            List<VipLevelSkuVO> vipLevelSkuList = group.get(vipLevel.getId());
            if (vipLevelSkuList == null) {
                vipLevelSkuList = Collections.emptyList();
            }
            vipLevel.setSkuList(vipLevelSkuList);
        }
    }
}
